"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoginService = void 0;
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const dotenv_1 = __importDefault(require("dotenv"));
const verifyUser_1 = require("../../utils/verifyUser");
const controlLicense_1 = require("../../utils/controlLicense");
const usuarioRepositories_1 = require("../../typeorm/repository/usuarioRepositories");
dotenv_1.default.config();
class LoginService {
    execute({ USUA_SIGLA, USUA_SENHA_APP, DATABASE, CNPJ }) {
        return __awaiter(this, void 0, void 0, function* () {
            const Tokenuuid = process.env.TOKEN_SECRET_REFRESH + '';
            try {
                const VerifyEmprBlock = yield usuarioRepositories_1.UsuarioRepository.query(`
        USE [MOBILE_CCONNECTION]
        SELECT  
          COAC_BLOCK
        FROM
          CONTROLE_ACESSO
        INNER JOIN
          DATA_CONNECTION
        ON
          DACO_COD = COAC_DACO_COD
        WHERE
          DACO_CNPJ = '${CNPJ}'
    `);
                if (VerifyEmprBlock[0].COAC_BLOCK === 'S') {
                    return ({
                        message: 'Empresa bloqueada',
                        error: true,
                        status: 403,
                        refreshToken: ''
                    });
                }
                const { message, error, status, userCod } = yield (0, verifyUser_1.verifyUserLogin)(USUA_SIGLA, USUA_SENHA_APP, DATABASE);
                if (error) {
                    return ({
                        message,
                        error,
                        status,
                        refreshToken: ''
                    });
                }
                const refreshToken = jsonwebtoken_1.default.sign({
                    USUA_SIGLA,
                    USUA_COD: userCod,
                    DATABASE
                }, Tokenuuid, {
                    expiresIn: '2h'
                });
                const { error: validLicenseError, message: validLicenseMessage, status: validLicenseStatus } = yield (0, controlLicense_1.ControlLicense)(USUA_SIGLA, CNPJ);
                if (validLicenseError) {
                    return ({
                        message: validLicenseMessage,
                        error: validLicenseError,
                        status: validLicenseStatus,
                        refreshToken: ''
                    });
                }
                const searchUser = yield usuarioRepositories_1.UsuarioRepository.query(`
        USE [MOBILE_CCONNECTION]
        SELECT 
          COUNT(USCM_USUA_SIGLA) AS CREATED
        FROM
          USER_CONTROL_MOBILE
        INNER JOIN
          DATA_CONNECTION
        ON
          DACO_COD = USCM_DACO_COD
        WHERE
          USCM_USUA_SIGLA = '${USUA_SIGLA}'
        AND
          DACO_CNPJ = '${CNPJ}' 
      `);
                if (searchUser[0].CREATED > 0) {
                    yield usuarioRepositories_1.UsuarioRepository.query(`
          USE [MOBILE_CCONNECTION]
          UPDATE 
            USER_CONTROL_MOBILE
          SET
            USCM_ATIVO = 'S',
            USCM_DATA_HORA_ENTRADA = GETDATE()
          WHERE
            USCM_USUA_SIGLA = '${USUA_SIGLA}'
        `);
                }
                else {
                    const dacoCod = yield usuarioRepositories_1.UsuarioRepository.query(`
          USE [MOBILE_CCONNECTION]
          SELECT
            DACO_COD
          FROM
            DATA_CONNECTION
          WHERE
            DACO_CNPJ = '${CNPJ}'
        `);
                    yield usuarioRepositories_1.UsuarioRepository.query(`
          USE [MOBILE_CCONNECTION]
          INSERT INTO
            USER_CONTROL_MOBILE
            (
              USCM_DATA_HORA_ENTRADA,
              USCM_ATIVO,
              USCM_USUA_SIGLA,
              USCM_DACO_COD
            )
          VALUES 
            (
              GETDATE(),
              'S',
              '${USUA_SIGLA}',
              ${dacoCod[0].DACO_COD}
            )
        `);
                }
                return ({
                    message: 'Login efetuado',
                    error: false,
                    status: 200,
                    refreshToken
                });
            }
            catch (e) {
                return ({
                    message: 'Internal server error' + e,
                    error: true,
                    status: 500,
                    refreshToken: ''
                });
            }
        });
    }
}
exports.LoginService = LoginService;
