import { PedidoEstoqueRepository } from '../../typeorm/repository/pedidoEstoqueRepositories'
import dotenv from 'dotenv'
import { countNumAprovAditivoContrato, updateAditivoContrato } from '../../queries/contractAdditive'
import { verifyUserLogin } from '../../utils/verifyUser'
dotenv.config()

interface IAdcsResponse {
    status: number;
    message: string;
    error: boolean;
}

export class ApprovalContractAdditive {
  public async execute (cod: string, ass: string, codCocs: string, password: string, database: string): Promise<IAdcsResponse> {
    try {
      const {
        message,
        error,
        status
      } = await verifyUserLogin(cod, password, database)

      if (error) {
        return ({
          message,
          error,
          status
        })
      }

      const selectPageNumAprova = await PedidoEstoqueRepository.query(`
        USE [${database}]
        SELECT 
          PAG2_NUM_APROVACOES_CONTR,
          PAG2_TODAS_APROVACOES_CONTR
        FROM 
          PARAMETROS_GERAIS_2
      `)

      const sql = countNumAprovAditivoContrato(codCocs, database)

      const selectQtdAprova = await PedidoEstoqueRepository.query(sql)

      let statusSQL = ''
      let pos = 0;

      if (selectPageNumAprova[0].PAG2_TODAS_APROVACOES_CONTR === 'S') {
        if (selectPageNumAprova[0].PAG2_NUM_APROVACOES_CONTR === 1) {
          pos = 1;
          statusSQL = ",ADCS_APROVADO = 'S'"
        } else if (selectPageNumAprova[0].PAG2_NUM_APROVACOES_CONTR === 2 && selectQtdAprova[0].NUM === 1) {
          pos = 2;
          statusSQL = ",ADCS_APROVADO = 'S'"
        } else if (selectPageNumAprova[0].PAG2_NUM_APROVACOES_CONTR === 3 && selectQtdAprova[0].NUM === 2) {
          pos = 3;
          statusSQL = ",ADCS_APROVADO = 'S'"
        } else if (selectPageNumAprova[0].PAG2_NUM_APROVACOES_CONTR === 4 && selectQtdAprova[0].NUM === 3) {
          pos = 4;
          statusSQL = ",ADCS_APROVADO = 'S'"
        }
      } else {
        pos = 1;
        statusSQL = ",ADCS_APROVADO = 'S'"
      }

      const sql2 = updateAditivoContrato(pos, codCocs, statusSQL, database)

      console.log(sql)
      console.log(sql2);
      console.log(selectQtdAprova);

      await PedidoEstoqueRepository.query(
        sql2
      )

      console.log(`Aditivo de contrato ${codCocs} aprovado com sucesso`)

      return {
        status: 200,
        message: `Aditivo de contrato ${codCocs} aprovado com sucesso`,
        error: false
      }
    } catch (e) {
      return ({
        message: 'Internal server error',
        error: true,
        status: 500
      })
    }
  }
}
